@@ -65,7 +65,7 @@ class TestOvercloudUpgradePrepare(fakes.TestOvercloudUpgradePrepare):
                          mock_write_overcloudrc,
                          mock_overcloudrc):
 
-        mock_stack = mock.Mock()
+        mock_stack = mock.Mock(parameters={'DeployIdentifier': ''})
         mock_stack.stack_name = 'mystack'
         mock_get_stack.return_value = mock_stack
         mock_yaml.return_value = {'fake_container': 'fake_value'}
@@ -91,6 +91,8 @@ class TestOvercloudUpgradePrepare(fakes.TestOvercloudUpgradePrepare):
         mock_write_overcloudrc.assert_called_once_with("mystack",
                                                        mock.ANY)
 
+    @mock.patch('tripleoclient.utils.get_stack',
+                autospec=True)
     @mock.patch('tripleoclient.utils.prepend_environment', autospec=True)
     @mock.patch('tripleoclient.workflows.package_update.update',
                 autospec=True)
@@ -101,9 +103,13 @@ class TestOvercloudUpgradePrepare(fakes.TestOvercloudUpgradePrepare):
     @mock.patch('tripleoclient.v1.overcloud_deploy.DeployOvercloud.'
                 '_deploy_tripleo_heat_templates', autospec=True)
     def test_upgrade_failed(self, mock_deploy, mock_copy, mock_yaml,
-                            mock_abspath, mock_open, mock_upgrade, add_env):
+                            mock_abspath, mock_open, mock_upgrade,
+                            add_env, mock_get_stack):
         mock_upgrade.side_effect = exceptions.DeploymentError()
         mock_yaml.return_value = {'fake_container': 'fake_value'}
+        mock_stack = mock.Mock(parameters={'DeployIdentifier': ''})
+        mock_stack.stack_name = 'overcloud'
+        mock_get_stack.return_value = mock_stack
         add_env = mock.Mock()
         add_env.return_value = True
         argslist = ['--stack', 'overcloud', '--templates', ]
